@@ -13,18 +13,20 @@ import simplejson as json
 from functools import wraps
 
 import pgadmin.browser.server_groups.servers.databases as databases
-from flask import render_template, make_response, request, jsonify
+from flask import render_template, request, jsonify
 from flask_babel import gettext
 from pgadmin.browser.collection import CollectionNodeModule
 from pgadmin.browser.server_groups.servers.utils import parse_priv_from_db, \
     parse_priv_to_db, validate_options, tokenize_options
 from pgadmin.browser.utils import PGChildNodeView
 from pgadmin.utils.ajax import make_json_response, internal_server_error, \
-    make_response as ajax_response
+    make_response as ajax_response, gone
 from pgadmin.utils.driver import get_driver
-from pgadmin.utils.ajax import gone
-
 from config import PG_DEFAULT_DRIVER
+from pgadmin.utils import IS_PY2
+# If we are in Python3
+if not IS_PY2:
+    unicode = str
 
 
 class ForeignDataWrapperModule(CollectionNodeModule):
@@ -62,6 +64,7 @@ class ForeignDataWrapperModule(CollectionNodeModule):
         self.max_ver = None
 
         super(ForeignDataWrapperModule, self).__init__(*args, **kwargs)
+        self.min_gpdbver = 1000000000
 
     def get_nodes(self, gid, sid, did):
         """
@@ -83,6 +86,14 @@ class ForeignDataWrapperModule(CollectionNodeModule):
         """
         return databases.DatabaseModule.NODE_TYPE
 
+    @property
+    def module_use_template_javascript(self):
+        """
+        Returns whether Jinja2 template is used for generating the javascript
+        module.
+        """
+        return False
+
 
 blueprint = ForeignDataWrapperModule(__name__)
 
@@ -100,10 +111,6 @@ class ForeignDataWrapperView(PGChildNodeView):
     * __init__(**kwargs)
       - Method is used to initialize the ForeignDataWrapperView and it's base view.
 
-    * module_js()
-      - This property defines (if javascript) exists for this node.
-        Override this property for your own logic
-
     * check_precondition()
       - This function will behave as a decorator which will checks
         database connection before running view, it will also attaches
@@ -176,24 +183,10 @@ class ForeignDataWrapperView(PGChildNodeView):
         'stats': [{'get': 'statistics'}],
         'dependency': [{'get': 'dependencies'}],
         'dependent': [{'get': 'dependents'}],
-        'module.js': [{}, {}, {'get': 'module_js'}],
         'get_handlers': [{}, {'get': 'get_handlers'}],
         'get_validators': [{}, {'get': 'get_validators'}]
     })
 
-    def module_js(self):
-        """
-        This property defines (if javascript) exists for this node.
-        Override this property for your own logic.
-        """
-        return make_response(
-            render_template(
-                "foreign_data_wrappers/js/foreign_data_wrappers.js",
-                _=gettext
-            ),
-            200, {'Content-Type': 'application/x-javascript'}
-        )
-
     def check_precondition(f):
         """
         This function will behave as a decorator which will checks
@@ -441,7 +434,9 @@ class ForeignDataWrapperView(PGChildNodeView):
 
         try:
             sql, name = self.get_sql(gid, sid, data, did, fid)
-
+            # Most probably this is due to error
+            if not isinstance(sql, (str, unicode)):
+                return sql
             status, res = self.conn.execute_scalar(sql)
             if not status:
                 return internal_server_error(errormsg=res)
@@ -535,7 +530,9 @@ class ForeignDataWrapperView(PGChildNodeView):
                 data[k] = v
         try:
             sql, name = self.get_sql(gid, sid, data, did, fid)
-
+            # Most probably this is due to error
+            if not isinstance(sql, (str, unicode)):
+                return sql
             if sql == '':
                 sql = "--modified SQL"
 
@@ -649,6 +646,10 @@ class ForeignDataWrapperView(PGChildNodeView):
         status, res = self.conn.execute_dict(sql)
         if not status:
             return internal_server_error(errormsg=res)
+        if len(res['rows']) == 0:
+            return gone(
+                _("Could not find the foreign data wrapper on the server.")
+            )
 
         is_valid_options = False
         if res['rows'][0]['fdwoptions'] is not None:
