@@ -21,8 +21,11 @@ from pgadmin.browser.utils import PGChildNodeView
 from pgadmin.utils.ajax import make_json_response, internal_server_error, \
     make_response as ajax_response, gone
 from pgadmin.utils.driver import get_driver
-
 from config import PG_DEFAULT_DRIVER
+from pgadmin.utils import IS_PY2
+# If we are in Python3
+if not IS_PY2:
+    unicode = str
 
 
 class FtsConfigurationModule(SchemaChildModule):
@@ -56,6 +59,7 @@ class FtsConfigurationModule(SchemaChildModule):
         self.max_ver = None
         self.manager = None
         super(FtsConfigurationModule, self).__init__(*args, **kwargs)
+        self.min_gpdbver = 1000000000
 
     def get_nodes(self, gid, sid, did, scid):
         """
@@ -481,6 +485,9 @@ class FtsConfigurationView(PGChildNodeView):
         )
         # Fetch sql query to update fts Configuration
         sql, name = self.get_sql(gid, sid, did, scid, data, cfgid)
+        # Most probably this is due to error
+        if not isinstance(sql, (str, unicode)):
+            return sql
         sql = sql.strip('\n').strip(' ')
         status, res = self.conn.execute_scalar(sql)
         if not status:
@@ -597,6 +604,10 @@ class FtsConfigurationView(PGChildNodeView):
 
         # Fetch sql query for modified data
         SQL, name = self.get_sql(gid, sid, did, scid, data, cfgid)
+        # Most probably this is due to error
+        if not isinstance(SQL, (str, unicode)):
+            return SQL
+
         if SQL == '':
             SQL = "-- No change"
 
