@@ -1,6 +1,6 @@
 define('pgadmin.node.schema', [
   'sources/gettext', 'sources/url_for', 'jquery', 'underscore',
-  'underscore.string', 'pgadmin', 'pgadmin.browser', 'backform', 'alertify',
+  'underscore.string', 'sources/pgadmin', 'pgadmin.browser', 'backform', 'alertify',
   'pgadmin.browser.collection', 'pgadmin.browser.server.privilege'
 ], function(gettext, url_for, $, _, S, pgAdmin, pgBrowser, Backform, alertify) {
 
@@ -13,7 +13,7 @@ define('pgadmin.node.schema', [
     initialize: function() {
       Backform.Control.prototype.initialize.apply(this, arguments);
       var self = this,
-          m = this.model;
+          m = this.model,
           url = self.field.get('url');
 
       if (url && m.isNew()) {
@@ -106,20 +106,6 @@ define('pgadmin.node.schema', [
     }
   };
 
-  pgBrowser.SecurityGroupUnderSchema = {
-    id: 'security', label: gettext('Security'), type: 'group',
-    // Show/Hide security group for nodes under the catalog
-    visible: function(args) {
-      if (args && 'node_info' in args) {
-        // If node_info is not present in current object then it might in its
-        // parent in case if we used sub node control
-        var node_info = args.node_info || args.handler.node_info;
-        return 'catalog' in node_info ? false : true;
-      }
-      return true;
-    }
-  };
-
   // Define Security Model with fields and validation for VacuumSettings Control
   var VacuumTableModel =  Backform.VacuumTableModel = pgBrowser.Node.Model.extend({
     defaults: {
@@ -457,9 +443,9 @@ define('pgadmin.node.schema', [
             return true;
 
             //Check if we are not child of catalog
-            prev_i = t.hasParent(i) ? t.parent(i) : null;
+          var prev_i = t.hasParent(i) ? t.parent(i) : null,
             prev_d = prev_i ? t.itemData(prev_i) : null;
-            if( prev_d && prev_d._type == 'catalog') {
+            if(prev_d && prev_d._type == 'catalog') {
               return false;
             }
           i = t.hasParent(i) ? t.parent(i) : null;
@@ -476,7 +462,7 @@ define('pgadmin.node.schema', [
           t = pgBrowser.tree;
 
       do {
-        d = t.itemData(i);
+        var d = t.itemData(i);
         if (
           d._type in pgBrowser.Nodes && pgBrowser.Nodes[d._type].hasId
         ) {
@@ -509,7 +495,8 @@ define('pgadmin.node.schema', [
           column = this.column,
           editable = this.column.get("editable"),
           input = this.$el.find('input[type=checkbox]').first(),
-          self_name = column.get('name');
+          self_name = column.get('name'),
+          is_editable;
 
         is_editable = _.isFunction(editable) ? !!editable.apply(column, [model]) : !!editable;
         if (is_editable) {
