@@ -71,6 +71,23 @@ class JobStepModule(CollectionNodeModule):
         """
         return 'pga_job'
 
+    @property
+    def csssnippets(self):
+        """
+        Returns a snippet of css to include in the page
+        """
+        snippets = [
+            render_template(
+                "pga_jobstep/css/pga_step.css",
+                node_type=self.node_type
+            )
+        ]
+
+        for submodule in self.submodules:
+            snippets.extend(submodule.csssnippets)
+
+        return snippets
+
     @property
     def module_use_template_javascript(self):
         """
