@@ -1,31 +1,7 @@
-(function(root, factory) {
-  // Set up Backform appropriately for the environment. Start with AMD.
-  if (typeof define === 'function' && define.amd) {
-    define(['sources/gettext', 'underscore', 'jquery', 'backbone', 'backform', 'backgrid', 'alertify', 'pgadmin.browser.node'],
-     function(gettext, _, $, Backbone, Backform, Backgrid, Alertify, pgNode) {
-      // Export global even in AMD case in case this script is loaded with
-      // others that may still expect a global Backform.
-      return factory(root, gettext, _, $, Backbone, Backform, Backgrid, Alertify, pgNode);
-    });
-
-  // Next for Node.js or CommonJS. jQuery may not be needed as a module.
-  } else if (typeof exports !== 'undefined') {
-    var _ = require('underscore') || root._,
-      $ = root.jQuery || root.$ || root.Zepto || root.ender,
-      Backbone = require('backbone') || root.Backbone,
-      Backform = require('backform') || root.Backform;
-      Backgrid = require('backgrid') || root.Backgrid;
-      Alertify = require('alertify') || root.Alertify;
-      pgAdmin = require('pgadmin.browser.node') || root.pgAdmin.Browser.Node,
-      gettext = require('sources/gettext') || root.gettext;
-    factory(root, gettext, _, $, Backbone, Backform, Alertify, pgNode);
-
-  // Finally, as a browser global.
-  } else {
-    factory(root, root.gettext, root._, (root.jQuery || root.Zepto || root.ender || root.$), root.Backbone, root.Backform, root.Backgrid, root.alertify, root.pgAdmin.Browser.Node);
-  }
-} (this, function(root, gettext, _, $, Backbone, Backform, Backgrid, Alertify, pgNode) {
-
+define(['sources/gettext', 'underscore', 'jquery', 'backbone', 'backform',
+  'backgrid', 'alertify', 'pgadmin.browser.node', 'pgadmin.browser.node.ui'
+  ],
+ function(gettext, _, $, Backbone, Backform, Backgrid, Alertify, pgNode) {
   /**
    * Each Privilege, supporeted by an database object, will be represented
    * using this Model.
@@ -627,7 +603,16 @@
        * focused active element.
        */
       setTimeout(function() {
-        if (self.$el[0] != document.activeElement && !isDescendant(self.$el[0], document.activeElement)){
+        /*
+         Do not close the control if user clicks outside dialog window,
+         only close the row if user clicks on add button or on another row, if user
+         clicks somewhere else then we will get tagName as 'BODY' or 'WINDOW'
+        */
+        var is_active_element = document.activeElement.tagName == 'DIV' ||
+                                document.activeElement.tagName == 'BUTTON';
+
+        if (is_active_element && self.$el[0] != document.activeElement &&
+                !isDescendant(self.$el[0], document.activeElement)) {
           var m = self.model;
           m.trigger('backgrid:edited', m, self.column, new Backgrid.Command(ev));
         }},10);
@@ -706,4 +691,4 @@
 
   return PrivilegeRoleModel;
 
-}));
+});
