@@ -21,8 +21,11 @@ from pgadmin.utils.ajax import make_json_response, \
     make_response as ajax_response, internal_server_error, gone
 from pgadmin.utils.ajax import precondition_required
 from pgadmin.utils.driver import get_driver
-
 from config import PG_DEFAULT_DRIVER
+from pgadmin.utils import IS_PY2
+# If we are in Python3
+if not IS_PY2:
+    unicode = str
 
 
 class TablespaceModule(CollectionNodeModule):
@@ -43,6 +46,14 @@ class TablespaceModule(CollectionNodeModule):
         """
         return servers.ServerModule.NODE_TYPE
 
+    @property
+    def module_use_template_javascript(self):
+        """
+        Returns whether Jinja2 template is used for generating the javascript
+        module.
+        """
+        return False
+
     @property
     def node_inode(self):
         return False
@@ -350,6 +361,10 @@ class TablespaceView(PGChildNodeView):
 
         try:
             SQL, name = self.get_sql(gid, sid, data, tsid)
+            # Most probably this is due to error
+            if not isinstance(SQL, (str, unicode)):
+                return SQL
+
             SQL = SQL.strip('\n').strip(' ')
             status, res = self.conn.execute_scalar(SQL)
             if not status:
@@ -433,6 +448,10 @@ class TablespaceView(PGChildNodeView):
                 data[k] = v
 
         sql, name = self.get_sql(gid, sid, data, tsid)
+        # Most probably this is due to error
+        if not isinstance(sql, (str, unicode)):
+            return sql
+
         sql = sql.strip('\n').strip(' ')
         if sql == '':
             sql = "--modified SQL"
@@ -458,6 +477,11 @@ class TablespaceView(PGChildNodeView):
             if not status:
                 return internal_server_error(errormsg=res)
 
+            if len(res['rows']) == 0:
+                return gone(
+                    _("Could not find the tablespace on the server.")
+                )
+
             # Making copy of output for further processing
             old_data = dict(res['rows'][0])
             old_data = self._formatter(old_data, tsid)
@@ -512,6 +536,10 @@ class TablespaceView(PGChildNodeView):
         if not status:
             return internal_server_error(errormsg=res)
 
+        if len(res['rows']) == 0:
+            return gone(
+                _("Could not find the tablespace on the server.")
+            )
         # Making copy of output for future use
         old_data = dict(res['rows'][0])
 
