@@ -23,7 +23,8 @@ class TableDdlFeatureTest(BaseFeatureTest):
                                                   self.server['username'],
                                                   self.server['db_password'],
                                                   self.server['host'],
-                                                  self.server['port'])
+                                                  self.server['port'],
+                                                  self.server['sslmode'])
         test_utils.drop_database(connection, "acceptance_test_db")
 
         test_utils.create_database(self.server, "acceptance_test_db")
@@ -51,5 +52,6 @@ class TableDdlFeatureTest(BaseFeatureTest):
                                                   self.server['username'],
                                                   self.server['db_password'],
                                                   self.server['host'],
-                                                  self.server['port'])
+                                                  self.server['port'],
+                                                  self.server['sslmode'])
         test_utils.drop_database(connection, "acceptance_test_db")
