@@ -8,5 +8,5 @@
 //////////////////////////////////////////////////////////////////////////
 
 define(function () {
-  return {}
+  return {};
 });
\ No newline at end of file
